##  for PCLinuxOS  ##

%define ver 0.3.5
%define rel 10

%define git 1
%define git_date 20180801
%if %{git}
%define realrel %{rel}.git%{git_date}.nora19
%else
%define realrel %{rel}.nora19
%endif

%define data_version 0.2.7

Name:    libkkc
Summary: Japanese Kana Kanji conversion library (libkkc)
Version: %{ver}
Release: %{realrel}
License: GPLv3+
Group:   System/Internationalization
URL:     https://github.com/ueno/libkkc

%if %{git}
Source0: %{name}-git%{git_date}.tar.xz
%else
Source0: https://github.com/ueno/libkkc/releases/download/v%{version}/%{name}-%{version}.tar.gz
%endif

#Patch0: libkkc-autogen_sh.patch

# Patch10 from openSUSE M17N repo.
Patch10: libkkc-typelib-sharelib.patch

BuildRequires: vala-devel
BuildRequires: libgee-devel
BuildRequires: libjson-glib-devel
BuildRequires: libgirepository-devel
BuildRequires: intltool
BuildRequires: gettext-devel
BuildRequires: marisa-devel
BuildRequires: marisa-python
BuildRequires: gnome-common

Requires: libkkc-common = %{version}-%{release}
Requires: libkkc-data >= %{data_version}
Requires: skkdic
Requires: lib64gee0.8_2
Requires: lib64json-glib1.0_0
Requires: marisa

%description
libkkc provides a converter from Kana-string to Kana-Kanji-mixed-string.
It was named after kkc.el in GNU Emacs, a simple Kana Kanji converter, while libkkc tries to convert sentences in a bit more complex way using N-gram language models.

# ----------------------------------------------

%package devel
Summary:  Header files and libraries for developing apps which will use libkkc
Group:    Development/C
Requires: %{name} = %{version}-%{release}

%description devel
The libkkc-devel package contains the header files and libraries.

# ----------------------------------------------

%package tools
Summary:  Tools for %{name}
Group:    Development/Tools
Requires: %{name} = %{version}-%{release}

%description tools
This package contains tools for developing applications that use libkkc.

# ----------------------------------------------

%package common
Summary:   Common data files for libkkc
Group:     System/Internationalization
BuildArch: noarch

%description common
This package contains the arch-independent data that libkkc uses at run time.

# ----------------------------------------------


%prep
%if %{git}
%setup -q -n %{name}-git%{git_date}
%else
%setup -q
%endif

#%%patch0 -p1
%patch10 -p1


%build
./autogen.sh \
 --prefix=%{_prefix} \
 --libdir=%{_libdir}  \
 --disable-static \
 --disable-silent-rules \
 --enable-introspection=yes \
 --enable-vala=yes \
 --enable-vapigen=yes

#%%configure2_5x --disable-static --disable-silent-rules --enable-introspection=yes --enable-vala=yes --enable-vapigen=yes

%make_build


%install
rm -rf $RPM_BUILD_ROOT
%makeinstall_std

# remove unneeded files
rm -f $RPM_BUILD_ROOT%{_libdir}/libkkc.la

%find_lang %{name}


%files -f %{name}.lang
%defattr(-,root,root,-)
%doc README COPYING AUTHORS NEWS data/rules/README.rules
%if ! %{git}
%doc ChangeLog
%endif
%{_libdir}/libkkc.so.*
%{_libdir}/girepository-1.0/Kkc-1.0.typelib

%files devel
%defattr(-,root,root,-)
%{_includedir}/libkkc/libkkc.h
%{_libdir}/libkkc.so
%{_libdir}/pkgconfig/kkc-1.0.pc
%{_datadir}/gir-1.0/Kkc-1.0.gir
%{_datadir}/vala/vapi/kkc-1.0.*

%files common
%defattr(-,root,root,-)
%{_datadir}/libkkc/templates/libkkc-data/*
%{_datadir}/libkkc/rules/*

%files tools
%defattr(-,root,root,-)
%{_bindir}/kkc
%{_bindir}/kkc-package-data


%changelog
* Sat Feb 02 2019 tomcat <> 0.3.5-10.git20180801
- update to git:20180801
- use new marisa builded with ruby-2.6.1

* Mon Jan 15 2018 tomcat <> 0.3.5-9.git20171220
- update to git:20171220
- drop Patch0

* Mon Oct 30 2017 tomcat <> 0.3.5-8.git20170328
- use 'R:lib64json-glib1.0_0' instead of 'R:json-glib'

* Mon Jun 26 2017 tomcat <> 0.3.5-7.git20170328
- add Patch10 from openSUSE M17N repo.

* Fri Jun 09 2017 tomcat <> 0.3.5-6.git20170328
- update to git:20170328

* Wed Apr 20 2016 tomcat <> 0.3.5-5.git20160317
- update to git:20160317

* Wed Feb 10 2016 tomcat <> 0.3.5-4.git20150522
- drop BR:python-argparse
- fix URL

* Mon May 25 2015 tomcat <> 0.3.5-3.git20150522
- update to git:20150522

* Fri May 15 2015 tomcat <> 0.3.5-2.git20150513
- update to git:20150513

* Mon Dec 29 2014 tomcat <> 0.3.5-1
- update to 0.3.5

* Mon Jul 07 2014 tomcat <> 0.3.4-1
- update to 0.3.4
- use libgee0.8 instead of libgee0.6
- use 'autogen.sh' on i586 arch

* Wed Apr 02 2014 tomcat <> 0.3.3-0.1
- update to 0.3.3
- do not use 'autogen.sh' on i586 arch

* Fri Dec 20 2013 tomcat <> 0.3.2-0.1
- update to 0.3.2
- add 'R:marisa-python'
- use 'autogen.sh' instead of %%configure2_5x
    add Patch0 again
    add 'BR:gnome-common' again

* Fri Nov 29 2013 tomcat <> 0.3.1-2
- sync official package
    create -common and -tools subpackages
    move %%{_bindir}/* from %%files to %%files tools
    move %%{_datadir}/kkc/* from %%files to %%files common
- use 'BR:marisa-devel' instead of marisa-trie-devel
- use 'R:marisa' instead of marisa-trie
- drop Patch0
- drop 'BR:gnome-common'

* Mon Sep 16 2013 tomcat <> 0.3.1-1
- update to 0.3.1

* Tue Jul 30 2013 tomcat <> 0.2.7-1
- update to 0.2.7

* Fri Jul 19 2013 tomcat <> 0.2.6-2
- use BR:libgee0.6-devel instead of libgee-devel on x86

* Sun Jul 07 2013 tomcat <> 0.2.6-1
- update to 0.2.6

* Wed Jun 19 2013 tomcat <> 0.2.4-2
- use BR:libgee0.6-devel instead of libgee-devel on x86_64

* Mon Jun 10 2013 tomcat <> 0.2.4-1
- update to 0.2.4
- use git trees source
- update Patch0

* Wed May 15 2013 tomcat <> 0.2.3-1
- update to 0.2.3

* Wed May 08 2013 tomcat <> 0.2.2-1
- update to 0.2.2

* Wed May 01 2013 tomcat <> 0.2.1-1
- update to 0.2.1

* Tue Apr 30 2013 tomcat <> 0.2.0-1
- update to 0.2.0
- build with marisa-trie-0.2.4

* Tue Mar 26 2013 tomcat <> 0.1.10-2
- rebuild with marisa-trie-0.2.2

* Tue Mar 19 2013 tomcat <> 0.1.10-1
- update to 0.1.10

* Sat Mar 02 2013 tomcat <> 0.1.8-1
- update to 0.1.8

* Fri Feb 22 2013 tomcat <> 0.1.7-1
- update to 0.1.7
- drop Patch1 merged upstream

* Wed Feb 13 2013 tomcat <> 0.1.6-1
- update to 0.1.6
- change License from GPLv3 to GPLv3+
- add document: data/rules/README.rules
- add Patch1 (work around for Python 2.6)

* Mon Feb 11 2013 tomcat <> 0.1.5-1
- update to 0.1.5

* Sun Feb 10 2013 tomcat <> 0.1.4-1
- update to 0.1.4

* Sat Feb 09 2013 tomcat <> 0.1.3-3
- Source0 get from git trees, because of against build error on x86_64
- add BR:libgirepository-devel
- add BR:gnome-common
- add BR:gettext-devel

* Sat Feb 09 2013 tomcat <> 0.1.3-2
- rebuild

* Thu Feb 07 2013 tomcat <> 0.1.3-1
- update to 0.1.3
- update %%files

* Wed Feb 06 2013 tomcat <> 0.1.2-2
- use R:%%{_lib}gee2 instead of R:libgee

* Tue Feb 05 2013 tomcat <> 0.1.2-1
- update to 0.1.2
- add Patch0

* Sat Feb 02 2013 tomcat <> 0.1.0-1
- initial build for PCLinuxOS imported from Vine Linux
